# mkdocstrings-twincat

[![ci](https://github.com/drehstromer/mkdocstrings-twincat/workflows/ci/badge.svg)](https://github.com/drehstromer/mkdocstrings-twincat/actions?query=workflow%3Aci)
[![documentation](https://img.shields.io/badge/docs-mkdocs-708FCC.svg?style=flat)](https://drehstromer.github.io/mkdocstrings-twincat/)
[![pypi version](https://img.shields.io/pypi/v/mkdocstrings-twincat.svg)](https://pypi.org/project/mkdocstrings-twincat/)

A Twincat handler for mkdocstrings.

## Installation

```bash
pip install mkdocstrings-twincat
```


